@@ -75,16 +75,16 @@ def load_creds(secrets=None):
     return df.to_dict(orient='records')[0]
 
 
-def connect_db(key='', name='', **kwargs):
+def connect_db(project_key='', project_name='', **kwargs):
     """Load deta.Base object that can be used to fetch items from our cloud
     database.
 
     Parameters
     ----------
-    key: str
-        "project_key". Should not expose this on github.
-    name: str
-        "project_name". This doesn't need to be private.
+    project_key: str
+        Deta "project_key". Should not expose this on github.
+    project_name: str
+        Deta "project_name". This doesn't need to be private.
     kwargs: any
         Extra kwargs are ignored. Just makes it so streamlit secrets is less
         brittle - we can include all deta creds without worrying about which
@@ -94,22 +94,25 @@ def connect_db(key='', name='', **kwargs):
     -------
     deta.base._Base
     """
-    if not (key and name):
-        key = DETA_CREDS['project_key']
-        name = DETA_CREDS['project_name']
+    if not (project_key and project_name):
+        kwargs.update(DETA_CREDS)
+        project_key = kwargs['project_key']
+        project_name = kwargs['project_name']
         warnings.warn(f'Missing key and/or name so defaulting to '
-                      f'{name} project creds.')
-    for obj in (key, name):
+                      f'{project_name} project creds.')
+    for obj in (project_key, project_name):
         if not isinstance(obj, str) or obj[0] == '{':
             raise ValueError(
                 'Input args should be strings. It looks like you might have '
                 f'passed in a dict or stringified dict by accident: {obj}'
             )
-    deta = Deta(key)
-    return deta.Base(name)
+    deta = Deta(project_key)
+    return deta.Base(project_name)
 
 
 try:
     DETA_CREDS = load_creds()
 except Exception as e:
-    warnings.warn(str(e))
+    warnings.warn('Deta credentials could not be loaded. DETA_CREDS will be '
+                  'initialized to an empty dict.\n' + str(e))
+    DETA_CREDS = {}
